import { OnInit } from '@angular/core';
import { AbstractControlOptions } from '@angular/forms';
export interface NrfControlOptions extends AbstractControlOptions {
    disabled: boolean;
}
/**
 * Input wrappers components should extends this class to pass constraints downwards
 */
export declare abstract class NrfControlOptionsComponent implements OnInit {
    /**
     * A list of Validators to validate the input and the update-on strategy
     */
    controlOptions: NrfControlOptions;
    /**
     * Sets this input to readonly and block any changes
     */
    disabled: boolean;
    /**
     * Define the lowest number value that this input should accept
     */
    min: string | number;
    /**
     * Define the maximum number value that this input should accept
     */
    max: string | number;
    /**
     * Set this input as required and fails when empty
     */
    required: boolean;
    /**
     * Set this input as an e-mail and validates the e-mail patter
     */
    email: boolean;
    /**
     * Define the minimum characters quantity this input should accept
     */
    minLength: string | number;
    /**
     * Define the maximum characters quantity this input should accept
     */
    maxLength: string | number;
    /**
     * Set a Regular Expression to match the input value against and fails if not match
     */
    pattern: string | RegExp;
    /**
     * The event name for control to update upon.
     */
    updateOn: 'change' | 'blur' | 'submit';
    /**
     * Cache the validators to enhance the performance
     */
    ngOnInit(): void;
    /**
     * Generate the control options based on the properties set in this component
     */
    generateControlOptions(): NrfControlOptions;
}
